# 2022-03-18 - Batch Relayer V2

> ⚠️ **DEPRECATED: do not use** ⚠️
>
> This relayer was deprecated in favor of an [updated version (also now deprecated)](../20220720-batch-relayer-v3) with more features.

Deployment of the second `BalancerRelayer` using `BatchRelayerLibrary`, for combining multiple operations (swaps, joins, etc.) in a single transaction. This version focuses on adding new wrapping functionality for various types of linear pools.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Polygon mainnet addresses](./output/polygon.json)
- [Arbitrum mainnet addresses](./output/arbitrum.json)
- [Goerli testnet addresses](./output/goerli.json)
- [`BatchRelayerLibrary` artifact](./artifact/BatchRelayerLibrary.json)
